Array API Standard Support: ``special``
=======================================

.. _array_api_support_special_cpu:

Support on CPU
--------------

.. array-api-support-per-function::
    :module: special
    :backend_type: cpu

.. _array_api_support_special_gpu:

Support on GPU
--------------

.. array-api-support-per-function::
    :module: special
    :backend_type: gpu

.. _array_api_support_special_jit:

Support with JIT
----------------

.. array-api-support-per-function::
    :module: special
    :backend_type: jit
